@@ -28,6 +28,7 @@ func TestCSS(t *testing.T) {
 		{"@font-face { x:y; }", "@font-face{x:y}"},
 
 		{"input[type=\"radio\"]{x:y}", "input[type=radio]{x:y}"},
+		{"input[type=\"radio\" i]{x:y}", "input[type=radio i]{x:y}"},
 		{"DIV{margin:1em}", "div{margin:1em}"},
 		{".CLASS{margin:1em}", ".CLASS{margin:1em}"},
 		{"@MEDIA all{}", "@media all{}"},
@@ -85,25 +86,68 @@ func TestCSSInline(t *testing.T) {
 		{"color: rgb(100%,100%,100%);", "color:#fff"},
 		{"color: rgba(255,0,0,1);", "color:red"},
 		{"color: rgba(255,0,0,2);", "color:red"},
-		{"color: rgba(255,0,0,0.5);", "color:rgba(255,0,0,.5)"},
-		{"color: rgba(255,0,0,-1);", "color:transparent"},
-		{"color: rgba(0%,15%,25%,0.2);", "color:rgba(0%,15%,25%,.2)"},
-		{"color: rgba(0,0,0,0.5);", "color:rgba(0,0,0,.5)"},
-		{"color: hsla(5,0%,10%,0.75);", "color:hsla(5,0%,10%,.75)"},
+		{"color: rgba(255,0,0,0.5);", "color:#ff000080"},
+		{"color: rgba(255,0,0,-1);", "color:#0000"},
+		{"color: rgba(0%,15%,25%,0.2);", "color:#00264033"},
+		{"color: rgba(0,0,0,0.5);", "color:#00000080"},
+		{"color: rgb(255 0 0 / 1);", "color:red"},
+		{"color: hsla(5,0%,10%,0.75);", "color:#1a1a1abf"},
 		{"color: hsl(0,100%,50%);", "color:red"},
 		{"color: hsla(1,2%,3%,1);", "color:#080807"},
-		{"color: hsla(1,2%,3%,0);", "color:transparent"},
+		{"color: hsla(1,2%,3%,0);", "color:#0000"},
 		{"color: hsl(48,100%,50%);", "color:#fc0"},
-		{"background: hsla(0,0%,100%,.7);", "background:hsla(0,0%,100%,.7)"},
+		{"color: hsl(0 100% 50% / 1);", "color:red"},
+		{"color: hsl(400, 150%, 150%, 2);", "color:#fff"},
+		{"background-position:top", "background-position:top"},
+		{"background-position:bottom", "background-position:bottom"},
+		{"background-position:center", "background-position:50%"},
+		{"background-position:left 50%", "background-position:0"},
+		{"background-position:center center", "background-position:50%"},
+		{"background-position:center bottom", "background-position:50% 100%"},
+		{"background-position:top right", "background-position:100% 0"},
+		{"background-position:bottom left", "background-position:0 100%"},
+		{"background-position:top center", "background-position:50% 0"},
+		{"background-position:bottom center", "background-position:50% 100%"},
+		{"background-position:bottom 5% right 0%", "background-position:bottom 5% right"},
+		{"background-position:bottom 0 right 10%", "background-position:bottom right 10%"},
+		{"background-position:center right 10%", "background-position:center right 10%"},
+		{"background-repeat:space space", "background-repeat:space"},
+		{"background-repeat:round round", "background-repeat:round"},
+		{"background-repeat:repeat repeat", "background-repeat:repeat"},
+		{"background-repeat:no-repeat no-repeat", "background-repeat:no-repeat"},
+		{"background-repeat:repeat no-repeat", "background-repeat:repeat-x"},
+		{"background-repeat:no-repeat repeat", "background-repeat:repeat-y"},
+		{"background-size:auto auto", "background-size:auto"},
+		{"background-size:30% auto", "background-size:30%"},
+		{"background: hsla(0,0%,100%,.7);", "background:#ffffffb2"},
+		{"background:red none", "background:red"},
+		{"background:red none 0 0", "background:red"},
+		{"background:red none 1 1", "background:red 1 1"},
+		{"background:#0000 1 1", "background:1 1"},
+		{"background:transparent", "background:0 0"},
+		{"background:transparent no-repeat", "background:no-repeat"},
+		{"background:#0000 none padding-box 0 0 / auto auto scroll border-box repeat repeat", "background:0 0"},
+		{"background:0 0 / auto", "background:0 0"},
+		{"background:0 0 / auto 10%", "background:0 0/auto 10%"},
+		{"background:0% 0%", "background:0 0"},
+		{"background:left top", "background:0 0"},
+		{"background:no-repeat repeat", "background:repeat-y"},
+		{"background:top right", "background:100% 0"},
+		{"background:bottom left", "background:0 100%"},
 		{"font-weight: bold; font-weight: normal;", "font-weight:700;font-weight:400"},
-		{"font: bold \"Times new Roman\",\"Sans-Serif\";", "font:700 times new roman,\"sans-serif\""},
+		{"font: bold 5px \"Times new Roman\",\"Sans-Serif\";", "font:700 5px times new roman,sans-serif"},
 		{"font: normal normal normal normal 20px normal", "font:20px normal"},
-		{"outline: none;", "outline:0"},
+		{"font:27px/13px arial,sans-serif", "font:27px/13px arial,sans-serif"},
+		{"font:normal normal bold normal medium/normal arial,sans-serif", "font:700 medium arial,sans-serif"},
+		{"font:400 medium/normal 'Arial'", "font:medium arial"},
+		{"font:medium/normal 'Arial'", "font:medium arial"},
+		{"outline: none;", "outline:none"},
 		{"outline: solid black 0;", "outline:solid #000 0"},
-		{"outline: none black 5px;", "outline:0 #000 5px"},
-		{"outline: none !important;", "outline:0!important"},
-		{"border-left: none;", "border-left:0"},
+		{"outline: none black medium;", "outline:#000"},
+		{"outline: none !important;", "outline:none!important"},
+		{"border-left: none;", "border-left:none"},
 		{"border-left: none 0;", "border-left:0"},
+		{"border-left: none medium currentcolor;", "border-left:none"},
 		{"border-left: 0 dashed red;", "border-left:0 dashed red"},
 		{"margin: 1 1 1 1;", "margin:1"},
 		{"margin: 1 2 1 2;", "margin:1 2"},
@@ -114,8 +158,6 @@ func TestCSSInline(t *testing.T) {
 		{"padding:.2em .4em .2em", "padding:.2em .4em"},
 		{"margin: 0em;", "margin:0"},
 		{"font-family:'Arial', 'Times New Roman';", "font-family:arial,times new roman"},
-		{"background:url('http://domain.com/image.png');", "background:url(http://domain.com/image.png)"},
-		{"background:url( 'http://domain.com/image.png' );", "background:url(http://domain.com/image.png)"},
 		{"filter: progid : DXImageTransform.Microsoft.BasicImage(rotation=1);", "filter:progid:DXImageTransform.Microsoft.BasicImage(rotation=1)"},
 		{"filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=0);", "filter:alpha(opacity=0)"},
 		{"content: \"a\\\nb\";", "content:\"ab\""},
@@ -123,7 +165,6 @@ func TestCSSInline(t *testing.T) {
 		{"content: \"\";", "content:\"\""},
 		{"x: white , white", "x:#fff,#fff"},
 
-		{"font:27px/13px arial,sans-serif", "font:27px/13px arial,sans-serif"},
 		{"text-decoration: none !important", "text-decoration:none!important"},
 		{"color:#fff", "color:#fff"},
 		{"border:2px rgb(255,255,255);", "border:2px #fff"},
@@ -142,22 +183,23 @@ func TestCSSInline(t *testing.T) {
 		//{"color:CYAN", "color:cyan"}, // TODO
 		{"width:attr(Name em)", "width:attr(Name em)"},
 		{"content:CounterName", "content:CounterName"},
+		{"background:url('http://domain.com/image.png');", "background:url(http://domain.com/image.png)"},
+		{"background:url( 'http://domain.com/image.png' );", "background:url(http://domain.com/image.png)"},
 		{"background:URL(x.PNG);", "background:url(x.PNG)"},
 		{"background:url(/*nocomment*/)", "background:url(/*nocomment*/)"},
 		{"background:url(data:,text)", "background:url(data:,text)"},
 		{"background:url('data:text/xml; version = 2.0,content')", "background:url(data:text/xml;version=2.0,content)"},
 		{"background:url('data:\\'\",text')", "background:url('data:\\'\",text')"},
 		{"margin:0 0 18px 0;", "margin:0 0 18px"},
-		{"background:none", "background:0 0"},
-		{"background:none 1 1", "background:none 1 1"},
-		{"background:transparent", "background:0 0"},
-		{"background:transparent no-repeat", "background:transparent no-repeat"},
 		{"z-index:1000", "z-index:1000"},
 		{"box-shadow:0 0 0 0", "box-shadow:0 0"},
 		{"flex:0px", "flex:0px"},
+		{"g:url('abc\\\ndef')", "g:url(abcdef)"},
+		{"url:local('abc\\\ndef')", "url:local(abcdef)"},
 
 		{"any:0deg 0s 0ms 0dpi 0dpcm 0dppx 0hz 0khz", "any:0 0s 0ms 0dpi 0dpcm 0dppx 0hz 0khz"},
 		{"width:calc(0%-0px)", "width:calc(0%-0px)"},
+		{"margin:calc(10px) calc(20px)", "margin:calc(10px) calc(20px)"},
 		{"border-left:0 none", "border-left:0"},
 		{"--custom-variable:0px;", "--custom-variable:0px"},
 		{"--foo: if(x > 5) this.width = 10", "--foo: if(x > 5) this.width = 10"},
@@ -204,6 +246,13 @@ func TestCSSKeepCSS2(t *testing.T) {
 		expected string
 	}{
 		{`margin:5000em`, `margin:5000em`},
+		{"color: rgba(0%,15%,25%,0.2);", "color:rgba(0%,15%,25%,.2)"},
+		{"color: hsla(5,0%,10%,0.75);", "color:hsla(5,0%,10%,.75)"},
+		{"color: rgba(0%,15%,25%,0);", "color:rgba(0%,15%,25%,0)"},
+		{"color: hsla(5,0%,10%,0);", "color:hsla(5,0%,10%,0)"},
+		{"color: rgba(0%,15%,25%,1);", "color:#002640"},
+		{"color: hsla(5,0%,10%,1);", "color:#1a1a1a"},
+		{"color: transparent;", "color:transparent"},
 	}
 
 	m := minify.New()
